HybridContentSearcher class

Combines exact BM25 lexical search with dense/vector search using RRF.

Implemented types

Constructors

HybridContentSearcher({required BM25LexicalIndex lexicalIndex, required Searcher semanticSearcher, int candidateLimit = 50, int rrfRankConstant = ReciprocalRankFusion.defaultRankConstant})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Searches lexical and semantic indexes, then fuses ranked lists with RRF.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited