ChunkEntity_ class

ChunkEntity entity fields to define ObjectBox queries.

Constructors

ChunkEntity_()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

chunkId QueryStringProperty<ChunkEntity>
See ChunkEntity.chunkId.
final
content QueryStringProperty<ChunkEntity>
See ChunkEntity.content.
final
id QueryIntegerProperty<ChunkEntity>
See ChunkEntity.id.
final
lineEnd QueryIntegerProperty<ChunkEntity>
See ChunkEntity.lineEnd.
final
lineStart QueryIntegerProperty<ChunkEntity>
See ChunkEntity.lineStart.
final
metadataJson QueryStringProperty<ChunkEntity>
See ChunkEntity.metadataJson.
final
sourcePath QueryStringProperty<ChunkEntity>
See ChunkEntity.sourcePath.
final
type QueryStringProperty<ChunkEntity>
See ChunkEntity.type.
final