BaseChunker class abstract
Base interface for all content chunkers.
A chunker breaks content into meaningful segments (chunks) that can be embedded and searched.
- Implementers
Constructors
Properties
- contentType → String
-
The type of content this chunker handles (e.g., 'dart', 'markdown').
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedExtensions
→ Set<
String> -
The set of file extensions (including the dot, e.g. '.dart', '.md')
or logical content types (e.g. 'text', 'markdown') this chunker supports.
no setter
Methods
-
canHandle(
String contentType) → bool - Whether this chunker can handle the given content type.
-
chunkContent(
String content, ChunkMetadata metadata) → List< Chunk> - Chunk content into segments.
-
chunkFile(
File file, {String? contentType}) → List< Chunk> - Chunk a file into segments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited