ReciprocalRankFusion class
Rank-based fusion for combining multiple retrieval result lists.
RRF avoids score normalization between retrieval methods by summing
1 / (rankConstant + rank) for each chunk across ranked lists.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fuse(
Iterable< List< rankedLists, {int limit = 5, int rankConstant = defaultRankConstant}) → List<SearchResult> >SearchResult> -
Fuses
rankedListsinto a single ranked result list.
Constants
- defaultRankConstant → const int
- Standard RRF rank constant used by common hybrid search systems.