KnowledgeSearchPolicy class
Explicit consumer policy, never written into an OKF document.
Constructors
Properties
- asOf → DateTime?
-
final
-
conceptTypes
→ Set<
String> -
final
- currentOnly → bool
-
Excludes deprecated/stale concepts, while retaining drafts and unverified
material. Use statuses for an explicitly historical or narrower query.
final
- expandRelationships → bool
-
final
-
governingSources
→ Map<
String, String> -
Lower-authority concept path -> governing concept path. No inference from
concept type, link label, verification tier, or similarity establishes it.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pathPrefixes
→ Set<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statuses
→ Set<
OkfLifecycleStatus> ? -
final
Methods
-
allows(
KnowledgeSnapshot snapshot, String path) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited